==> kie-wb-common-cli-project-migration-7.37.0.Final-test-sources.jar: org/kie/workbench/common/project/config/MigrationConfigurationFactoryImplTest.java <==
/*
 * Copyright 2018 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.kie.workbench.common.project.config;

import org.guvnor.structure.backend.config.DefaultPasswordServiceImpl;
import org.guvnor.structure.server.config.ConfigGroup;
import org.guvnor.structure.server.config.ConfigType;
import org.guvnor.structure.server.config.ConfigurationFactory;
import org.guvnor.structure.server.config.PasswordService;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.runners.MockitoJUnitRunner;

import static org.junit.Assert.*;

@RunWith(MockitoJUnitRunner.class)
public class MigrationConfigurationFactoryImplTest {

    private PasswordService passwordService;

    private ConfigurationFactory configurationFactory;

    @Before
    public void setup() {
        passwordService = new DefaultPasswordServiceImpl();
        configurationFactory = new MigrationConfigurationFactoryImpl(passwordService);
    }

    @Test
    public void newConfigGroupWithoutNamespaceTest() {
        final ConfigGroup configGroup = configurationFactory.newConfigGroup(ConfigType.GLOBAL,
                                                                            "my-config",
                                                                            "my-description");

        assertEquals(ConfigType.GLOBAL,
                     configGroup.getType());
        assertEquals("my-config",
                     configGroup.getName());
        assertEquals("my-description",
                     configGroup.getDescription());
        assertTrue(configGroup.isEnabled());
    }

    @Test
    public void newConfigGroupWithNamespaceTest() {
        final ConfigGroup configGroup = configurationFactory.newConfigGroup(ConfigType.REPOSITORY,
                                                                            "my-namespace",
                                                                            "my-config",
                                                                            "my-description");

        assertEquals(ConfigType.REPOSITORY,
                     configGroup.getType());
        assertEquals("my-config",
                     configGroup.getName());
        assertEquals("my-description",
                     configGroup.getDescription());
        assertTrue(configGroup.isEnabled());
    }
}

==> kie-wb-common-cli-project-migration-7.65.0.Final-test-sources.jar: org/kie/workbench/common/project/config/MigrationConfigurationFactoryImplTest.java <==
/*
 * Copyright 2018 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.kie.workbench.common.project.config;

import org.guvnor.structure.backend.config.DefaultPasswordServiceImpl;
import org.guvnor.structure.server.config.ConfigGroup;
import org.guvnor.structure.server.config.ConfigType;
import org.guvnor.structure.server.config.ConfigurationFactory;
import org.guvnor.structure.server.config.PasswordService;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.junit.MockitoJUnitRunner;

import static org.junit.Assert.*;

@RunWith(MockitoJUnitRunner.class)
public class MigrationConfigurationFactoryImplTest {

    private PasswordService passwordService;

    private ConfigurationFactory configurationFactory;

    @Before
    public void setup() {
        passwordService = new DefaultPasswordServiceImpl();
        configurationFactory = new MigrationConfigurationFactoryImpl(passwordService);
    }

    @Test
    public void newConfigGroupWithoutNamespaceTest() {
        final ConfigGroup configGroup = configurationFactory.newConfigGroup(ConfigType.GLOBAL,
                                                                            "my-config",
                                                                            "my-description");

        assertEquals(ConfigType.GLOBAL,
                     configGroup.getType());
        assertEquals("my-config",
                     configGroup.getName());
        assertEquals("my-description",
                     configGroup.getDescription());
        assertTrue(configGroup.isEnabled());
    }

    @Test
    public void newConfigGroupWithNamespaceTest() {
        final ConfigGroup configGroup = configurationFactory.newConfigGroup(ConfigType.REPOSITORY,
                                                                            "my-namespace",
                                                                            "my-config",
                                                                            "my-description");

        assertEquals(ConfigType.REPOSITORY,
                     configGroup.getType());
        assertEquals("my-config",
                     configGroup.getName());
        assertEquals("my-description",
                     configGroup.getDescription());
        assertTrue(configGroup.isEnabled());
    }
}
